@@ -1,4 +1,13 @@
 #!/usr/bin/perl
+#
+# This file is part of CPAN-WWW-Top100-Retrieve
+#
+# This software is copyright (c) 2014 by Apocalypse.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
+use strict; use warnings;
 use strict; use warnings;
 
 use CPAN::WWW::Top100::Retrieve;
